==> haskell-djinn-ghc-0.0.2.3-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-ghc
version:              0.0.2.3
visibility:           public
id:                   djinn-ghc-0.0.2.3-7gmAqIw4K8PG2WmGnyG9Me
key:                  djinn-ghc-0.0.2.3-7gmAqIw4K8PG2WmGnyG9Me
license:              BSD-3-Clause
maintainer:           trupill@gmail.com   
author:               Alejandro Serrano
synopsis:
    Generate Haskell code from a type. Bridge from Djinn to GHC API.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is the bridge from djinn-lib to GHC API.

category:             Language
abi:                  bd83e2b7b17270d9b1ba2350a15e7fd3
exposed:              True
exposed-modules:      Djinn.GHC
import-dirs:          /usr/lib/ghc-8.10.2/site-local/djinn-ghc-0.0.2.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/djinn-ghc-0.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/djinn-ghc-0.0.2.3
hs-libraries:         HSdjinn-ghc-0.0.2.3-7gmAqIw4K8PG2WmGnyG9Me
depends:
    async-2.2.2-9B1GNjZqSi02JrVTPPwupP base-4.14.1.0 containers-0.6.2.1
    djinn-lib-0.0.1.3-5XQMRIW3Cz21joN2SK3nHm ghc-8.10.2 mtl-2.2.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-djinn-ghc/html/djinn-ghc.haddock
haddock-html:         /usr/share/doc/haskell-djinn-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-ghc-0.0.2.3-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-ghc
version:              0.0.2.3
visibility:           public
id:                   djinn-ghc-0.0.2.3-GBmOQ4nRqcfQduOzvS0El
key:                  djinn-ghc-0.0.2.3-GBmOQ4nRqcfQduOzvS0El
license:              BSD-3-Clause
maintainer:           trupill@gmail.com   
author:               Alejandro Serrano
synopsis:
    Generate Haskell code from a type. Bridge from Djinn to GHC API.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is the bridge from djinn-lib to GHC API.

category:             Language
abi:                  4b22c20d87155e7a1239856d0864f7e4
exposed:              True
exposed-modules:      Djinn.GHC
import-dirs:          /usr/lib/ghc-8.10.2/site-local/djinn-ghc-0.0.2.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/djinn-ghc-0.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/djinn-ghc-0.0.2.3
hs-libraries:         HSdjinn-ghc-0.0.2.3-GBmOQ4nRqcfQduOzvS0El
depends:
    async-2.2.2-jxGH4UpsLnJzlVwCtt2o5 base-4.14.1.0 containers-0.6.2.1
    djinn-lib-0.0.1.3-5XQMRIW3Cz21joN2SK3nHm ghc-8.10.2 mtl-2.2.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-djinn-ghc/html/djinn-ghc.haddock
haddock-html:         /usr/share/doc/haskell-djinn-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
